Parsons Directive
=================

The master repository for the parsons problems code is https://github.com/vkaravir/js-parsons.git

If you want to make customizations ONLY for runestone you should use the fork at https://github.com/bnmnetp/js-parsons.git

